@@ -1,7 +1,7 @@
 
 /*  $Header$
  *
- *  Copyright (c) 1987-2007 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -83,6 +83,7 @@ enum
     KEY_ADD, KEY_SUBTRACT,
     KEY_MULTIPLY, KEY_DIVIDE,
     KEY_BACKSPACE,
+    KEY_DELETE,        
     KEY_CHANGE_SIGN,
     KEY_INTEGER,
     KEY_FRACTION,
@@ -100,6 +101,7 @@ enum
     KEY_TAN, KEY_TANH, KEY_ATAN, KEY_ATANH,
     KEY_NATURAL_LOGARITHM,
     KEY_LOGARITHM,
+    KEY_LOGARITHM2,
     KEY_ABSOLUTE_VALUE,
     KEY_MASK_16,
     KEY_MASK_32,
@@ -184,6 +186,7 @@ struct exprm_state {
     int ans[MP_SIZE];      /* Previously calculated answer */
     char *expression;      /* Expression entered by user */
     int cursor;
+    int clear;             /* Clear command issued */
 };
 
 /* Circular list of Arithmetic Precedence Mode states*/ 
@@ -205,10 +208,10 @@ struct calcVars {                      /* Calctool variables and options. */
     
     char display[MAXLINE];             /* Current calculator display. */
     char *exp_posn;                    /* Position of the exponent sign. */
-    char fnum[MAX_DIGITS];             /* Scratchpad for fixed numbers. */
+    char fnum[MAX_LOCALIZED];          /* Scratchpad for fixed numbers. */
     const char *radix;                 /* Locale specific radix string. */
     char *shelf;                       /* PUT selection shelf contents. */
-    char snum[MAX_DIGITS];             /* Scratchpad for scientific numbers. */
+    char snum[MAX_LOCALIZED];          /* Scratchpad for scientific numbers. */
     const char *tsep;                  /* Locale specific thousands seperator. */
 
     char fun_names[MAX_FUNCTIONS][MAXLINE];  /* Function names from .gcalctoolcf. */
