@@ -1,7 +1,7 @@
 
 /*  $Header$
  *
- *  Copyright (c) 1987-2007 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,9 @@ char *make_number(int *, int, int);
 void clear_display(int);
 void MPstr_to_num(char *, enum base_type, int *);
 void paren_disp(int);
-void refresh_display();
+void refresh_display(int);
 void show_display(int *);
 void process_item(struct button *, int);
+gboolean display_is_result(void);
 
 #endif /* DISPLAY_H */
